## Install packages
install.packages("dplyr")
install.packages("ggplot2")
install.packages("fuzzyjoin")

## Import Library
library("dplyr")
library("ggplot2")
library("fuzzyjoin")

## Read mass data and select column
df_MS1 <- read.csv("Tea_MS1.csv")
df_MS1 <- df_MS1 %>% 
  select(SMP, Injection_Id, Peak_Name, Retention_Time) %>% 
  mutate(RT_min = Retention_Time+0.06, RT_max=Retention_Time+0.09) %>% 
  select(SMP, Injection_Id, Peak_Name, RT_min, RT_max) 
head(df_MS1,3)

df_MS2 <- read.csv("Tea_MS2.csv")
df_MS2 <- df_MS2 %>% 
  select(SMP, Injection_Id, Peak_Name, Retention_Time) %>% 
  mutate(RT_min = Retention_Time+0.06, RT_max=Retention_Time+0.09) %>% 
  select(SMP, Injection_Id, Peak_Name, RT_min, RT_max) 
head(df_MS2,3)

## Read mass data and select column
df_UV1 <- read.csv("Tea_UV_275.csv")
df_UV1 <- df_UV1 %>% 
  select(Inj_Id, Retention_Time, Area, Dilution)
df_UV2 <- read.csv("Tea_UV_365.csv")
df_UV2 <- df_UV2 %>% 
  select(Inj_Id, Retention_Time, Area, Dilution)

## Join data frame with conditons
df_MS3 <- fuzzy_inner_join(df_MS1, df_UV1, 
                by=c("Injection_Id"="Inj_Id","RT_min"="Retention_Time", "RT_max"="Retention_Time"),
                match_fun=list(`==`, `<=`, `>=`)) %>% 
  select(SMP, Injection_Id, Peak_Name, Retention_Time, Area, Dilution)
df_MS4 <- fuzzy_inner_join(df_MS2, df_UV2, 
                           by=c("Injection_Id"="Inj_Id","RT_min"="Retention_Time", "RT_max"="Retention_Time"),
                           match_fun=list(`==`, `<=`, `>=`)) %>% 
  select(SMP, Injection_Id, Peak_Name, Retention_Time, Area, Dilution)

## Re-calculation of compounds concentration 
df_MS3 <- df_MS3 %>% 
mutate (Re_amount = ifelse(Peak_Name =="C",(Area - 6.88e+002)/(5.83e+003),
                           ifelse(Peak_Name =="Caffeine",(Area - 7.52e+002)/(2.37e+004),
                                 ifelse(Peak_Name =="CG",(Area - 6.15e+002)/(1.22e+004),
                                        ifelse(Peak_Name =="EC",(Area - 4.99e+002)/(4.41e+003),
                                               ifelse(Peak_Name =="ECG",(Area - 1.03e+003)/(1.28e+004),
                                                      ifelse(Peak_Name =="EGC",(Area - 7.11e+002)/(3.18e+003),
                                                             ifelse(Peak_Name =="EGCG",(Area - 5.88e+002)/(1.04e+004),
                                                                    ifelse(Peak_Name =="Gallic acid",(Area - 4.80e+002)/(1.26e+004),
                                                                           ifelse(Peak_Name =="GC",(Area - 1.02e+002)/(1.81e+003),
                                                                                  ifelse(Peak_Name =="GCG",(Area - 7.18e+002)/(9.73e+003),
                                                                                         ifelse(Peak_Name =="TF1",(Area - 1.07e+003)/(1.15e+004),
                                                                                                ifelse(Peak_Name =="TF2a",(Area - 4.47e+002)/(8.37e+003),
                                                                                                       ifelse(Peak_Name =="TF2b",(Area - 2.40e+003)/(1.47e+004),
                                                                                                              ifelse(Peak_Name =="TF3",(Area - 2.02e+002)/(1.62e+004),NA)))))))))))))))
df_MS3 <- df_MS3 %>% 
  mutate (Re_value = Re_amount*1000/Dilution) 

df_MS4 <- df_MS4 %>% 
  mutate (Re_amount = ifelse(Peak_Name =="Apigenin",(Area - 7.60e+002)/(1.77e+004),
                             ifelse(Peak_Name =="Isoquercitrin",(Area - 6.30e+002)/(1.32e+004),
                                    ifelse(Peak_Name =="Kaempferol",(Area - 7.14e+002)/(2.32e+004),
                                           ifelse(Peak_Name =="Myricetin",(Area - 2.60e+002)/(3.06e+004),
                                                  ifelse(Peak_Name =="Quercetin",(Area - 3.85e+002)/(2.59e+004),
                                                         ifelse(Peak_Name =="Rutin",(Area - 5.07e+002)/(1.05e+004),NA)))))))

df_MS4 <- df_MS4 %>% 
  mutate (Re_value = Re_amount*1000/Dilution) 

## Combine data frames
df_Result <- bind_rows(df_MS3, df_MS4)
write.csv(df_Result, file = "5Tea_results.csv")

summary_df_Result <- df_Result %>% 
  group_by(SMP, Peak_Name) %>% 
  summarise(mean_Re_value = mean(Re_value), SEM_Re_value = sd(Re_value)/(sqrt(length(Re_value))))

install.packages("pivottabler")
library(pivottabler)
pivot_df_Result <- qhpvt(summary_df_Result, "Peak_Name", "SMP",
      c("mean_Re_value", "SEM_Re_value"),
      formats=list(".2f",".2f"))

install.packages("reshape2")
library(reshape2)
pivot_df_Result <- dcast(summary_df_Result, Peak_Name ~ SMP, value.var = "mean_Re_value"+"")

write.csv(summary_df_Result, file = "5Tea_results.csv")
